@@ -86,6 +86,8 @@
 #define ICON_BAR4 ICON_DIR"la_in_bar_4.png"
 #define ICON_TEST ICON_DIR"la_test.png"
 
+#define SHUTTER_SOUND   "/usr/share/sounds/la_shutter_sound.wav"
+
 #define CPUFILE "/proc/stat"
 #define MEMFILE "/proc/meminfo"
 #define SWAPFILE "/proc/swaps" 
@@ -126,7 +128,8 @@ typedef struct
     gboolean on_border;
     gboolean on_button;
     gboolean button_released;
-	gboolean llscreenshots;
+    gboolean llscreenshots;
+    gboolean shutter_sound;
     /* Internal data */
     guchar last_cpu_level;
     guchar last_mem_level;
@@ -159,6 +162,9 @@ gint load_get_priority(void *data);
 void load_update(void *data, gint value1, gint value2, const gchar *str);
 static void hildon_im_hw_cb(osso_hw_state_t*, gpointer);
 
+/* Function for embedding the icon */
+int embed_applet(GtkWidget *item, GtkWidget **button);
+
 /* Internal function prototypes */
 static gboolean check_load_cpu (gpointer);
 static GdkPixbuf* la_load_pixmap(const gchar*);
@@ -499,6 +505,11 @@ errorhandler:
 }
 
 
+static void play_shutter_sound()
+{
+    hildon_play_system_sound(SHUTTER_SOUND);
+}
+
 
 static void
 activate_screenshot_item(GtkMenuItem *item, gpointer data)
@@ -517,6 +528,9 @@ make_screenshot_tcb(gpointer data)
 	else
 		make_screenshot();
 	
+        if(info->shutter_sound)
+            play_shutter_sound();
+
 	return FALSE; /* Do not call this again */
 }
 
@@ -532,11 +546,12 @@ activate_settings_item(GtkMenuItem *item, gpointer data)
 {
 	GtkWidget *dialog;
 	GtkWidget *button_accept, *button_cancel;
-	GtkWidget *vbox, *hboxtop, *hboxbottom, *hboxll;
+	GtkWidget *vbox, *hboxtop, *hboxbottom, *hboxll, *hboxsound;
 	GtkWidget *labeldelay, *labelfilename;
 	GtkWidget *sb_seconds;
 	GtkWidget *entry_filename;
 	GtkWidget *llcheck;
+        GtkWidget *shutter_sound_button;
 	gint result;
 
 	dialog = gtk_dialog_new_with_buttons ("Screenshot settings", NULL, GTK_DIALOG_MODAL, NULL);
@@ -571,6 +586,12 @@ activate_settings_item(GtkMenuItem *item, gpointer data)
 	gtk_box_pack_start (GTK_BOX(hboxll), llcheck, TRUE, TRUE, 5);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (llcheck), info->llscreenshots);
 
+        /* Fake shutter sound */
+        hboxsound = gtk_hbox_new (FALSE, 5);
+        gtk_box_pack_start (GTK_BOX(vbox), hboxsound, TRUE, TRUE, 2);
+        shutter_sound_button = gtk_check_button_new_with_label ("Fake shutter sound");
+        gtk_box_pack_start (GTK_BOX(hboxsound), shutter_sound_button, TRUE, TRUE, 5);
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (shutter_sound_button), info->shutter_sound);
 	
 	hildon_help_dialog_help_enable (GTK_DIALOG(dialog), "Settings_LoadApplet_Main", info->osso_context);
 	gtk_widget_show_all(dialog);
@@ -587,6 +608,7 @@ activate_settings_item(GtkMenuItem *item, gpointer data)
 		sshotfilename = g_strdup(gtk_entry_get_text(GTK_ENTRY(entry_filename)));
 		screenshot_delay = hildon_number_editor_get_value (HILDON_NUMBER_EDITOR(sb_seconds));
 		info->llscreenshots = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (llcheck));
+                info->shutter_sound = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (shutter_sound_button));
 		gtk_widget_destroy(dialog);
 		break;
 	default:
@@ -983,7 +1005,8 @@ load_initialize(HildonStatusBarItem *item,
     info->last_cpu_level = 0;
     info->last_mem_level = 0;
     info->is_swap_used = FALSE;
-	info->llscreenshots = FALSE;
+    info->llscreenshots = FALSE;
+    info->shutter_sound = FALSE;
     
     return info;
 }
@@ -1042,3 +1065,52 @@ load_get_priority(void *data)
 {
     return HILDON_STATUS_BAR_LOAD_PRIORITY;
 }
+
+
+int embed_applet(GtkWidget *item, GtkWidget **button)
+{
+
+    GdkColor bg_color;
+    gdk_color_parse ("black", &bg_color);
+
+    info = g_new0(PluginInfo, 1);
+
+    g_return_val_if_fail(info, 1);
+    g_return_val_if_fail(button, 1);
+
+    bindtextdomain(PACKAGE, LOCALEDIR);
+
+    info->item = (HildonStatusBarItem *)item;
+    info->icon = gtk_image_new_from_pixbuf(NULL);
+    info->button = gtk_toggle_button_new();
+
+    gtk_widget_modify_bg(info->button, GTK_STATE_NORMAL, &bg_color);
+                      
+    gtk_container_add(GTK_CONTAINER(info->button),
+                      GTK_WIDGET(info->icon));
+    
+    *button = info->button;
+    
+    g_signal_connect(G_OBJECT(info->button), "pressed",
+                     G_CALLBACK(load_icon_pressed),
+                     info);
+
+    la_load_pixmaps();
+    
+    gtk_image_set_from_pixbuf(GTK_IMAGE(info->icon), info->pixbuf_current);
+    gtk_widget_show_all(GTK_WIDGET(info->button));
+
+    /* Install timeout handler for updating */
+    info->timeout_id = gtk_timeout_add(1000, check_load_cpu, info);
+
+    /* Screenshot stuff too */
+    sshotfilename = g_strdup(SSHOT_DEFAULT_NAME);
+    info->last_cpu_level = 0;
+    info->last_mem_level = 0;
+    info->is_swap_used = FALSE;
+    info->llscreenshots = FALSE;
+    info->shutter_sound = FALSE;
+    
+    return 0;
+}
+
